@@ -5,7 +5,13 @@ snapshot file.
 """
 
 from .readers import load_snap
-from .snap import Snap, SnapLike
+from .snap import Snap, SnapLike, SubSnap
 from .units import gravitational_constant_in_code_units
 
-__all__ = ['Snap', 'SnapLike', 'gravitational_constant_in_code_units', 'load_snap']
+__all__ = [
+    'Snap',
+    'SnapLike',
+    'SubSnap',
+    'gravitational_constant_in_code_units',
+    'load_snap',
+]
