@@ -3,6 +3,7 @@
 from pathlib import Path
 from typing import Union
 
+from ... import logger
 from ..snap import Snap
 from .phantom import generate_snap_from_file as read_phantom
 
@@ -30,5 +31,13 @@ def load_snap(filename: Union[str, Path], data_source: str = 'Phantom') -> Snap:
         )
 
     if data_source == 'Phantom':
-        return read_phantom(filename)
-    raise ValueError('Cannot load snapshot')
+        try:
+            return read_phantom(filename)
+        except FileNotFoundError as e:
+            logger.error(f'File not found: {filename}')
+            raise e
+        except OSError as e:
+            # Catch errors raised by h5py due to file corruption
+            logger.error(f'File likely corrupted: {filename}')
+            raise e
+    raise RuntimeError('Cannot load snap')
