@@ -614,6 +614,59 @@ class Snap:
             ]
         return np.flatnonzero(self['type'] == self.particle_type[particle_type])
 
+    def subsnaps_by_type(
+        self, split_subtypes: bool = True
+    ) -> Dict[str, Union[SubSnap, List[SubSnap]]]:
+        """Return particle-type subsnaps as a dict of SubSnaps.
+
+        Parameters
+        ----------
+        split_subtypes : optional
+            If True, split particle types into subtypes.
+
+        Returns
+        -------
+        A dict of all SubSnaps.
+        """
+        if not split_subtypes:
+            raise NotImplementedError('Combined sub-types not implemented yet')
+        subsnaps_by_type: Dict[str, Any] = dict()
+        for key in self.particle_type:
+            try:
+                subsnap = self[key]
+                if isinstance(subsnap, list):
+                    if len(subsnap[0]) > 0:
+                        subsnaps_by_type[key] = self[key]
+                else:
+                    if len(subsnap) > 0:
+                        subsnaps_by_type[key] = self[key]
+            except ValueError:
+                pass
+
+        return subsnaps_by_type
+
+    def subsnaps_as_list(self, split_subtypes: bool = True) -> List[SubSnap]:
+        """Return particle-type subsnaps as a list of SubSnaps.
+
+        Parameters
+        ----------
+        split_subtypes : optional
+            If True, split particle types into subtypes.
+
+        Returns
+        -------
+        A list of all SubSnaps.
+        """
+        if not split_subtypes:
+            raise NotImplementedError('Combined sub-types not implemented yet')
+        subsnaps: List[SubSnap] = list()
+        for val in self.subsnaps_by_type().values():
+            if isinstance(val, list):
+                subsnaps = subsnaps + val
+            else:
+                subsnaps.append(val)
+        return subsnaps
+
     def set_kernel(self, kernel: str):
         """Set kernel.
 
@@ -1145,7 +1198,7 @@ class SubSnap(Snap):
 
     def __str__(self):
         """Dunder str method."""
-        return f'<plonk.SubSnap>'
+        return self.base.__str__().replace('Snap', 'SubSnap')
 
     def _get_array(self, name: str, sinks: bool = False) -> ndarray:
         return self.base._get_array(name, sinks)[self.indices]
