@@ -1,4 +1,4 @@
-"""Plot functions for visualization."""
+"""Matplotlib wrapper functions for visualization."""
 
 from copy import copy
 from typing import Any, Optional
@@ -11,9 +11,7 @@ from .. import logger
 from .interpolation import Extent
 
 
-def plot(
-    *, x: ndarray, y: ndarray, ax: Any, **kwargs,
-):
+def plot(*, x: ndarray, y: ndarray, ax: Any, **kwargs):
     """Plot particles.
 
     Parameters
@@ -33,16 +31,17 @@ def plot(
         A list of matplotlib Line2D objects.
     """
     _kwargs = copy(kwargs)
-    fmt = _kwargs.pop('fmt', 'k.')
-    return ax.plot(x, y, fmt, **_kwargs)
+    linestyle = _kwargs.pop('linestyle', '')
+    marker = _kwargs.pop('marker', '.')
+    return ax.plot(x, y, linestyle=linestyle, marker=marker, **_kwargs)
 
 
 def scatter(
     *,
     x: ndarray,
     y: ndarray,
-    color: Optional[ndarray] = None,
-    size: Optional[ndarray] = None,
+    c: Optional[ndarray] = None,
+    s: Optional[ndarray] = None,
     n_samples=10_000,
     random_seed=None,
     ax: Any,
@@ -56,9 +55,9 @@ def scatter(
         The x-coordinates for the scatter plot.
     y
         The y-coordinates for the scatter plot.
-    color
+    c
         The quantity to color the particles.
-    size
+    s
         The quantity to set the particle size.
     n_samples
         The number of samples to take. Default is 10,000.
@@ -74,7 +73,7 @@ def scatter(
     paths
         A matplotlib PathCollection object.
     """
-    if color is None and size is None:
+    if c is None and s is None:
         raise ValueError('Should set size or color')
     if n_samples > 100_000:
         logger.warning('n_samples > 100,000: this may be slow')
@@ -85,20 +84,18 @@ def scatter(
 
     x = x[rand]
     y = y[rand]
-    if color is not None:
-        color = color[rand]
-    if size is not None:
-        size = size[rand]
+    if c is not None:
+        c = c[rand]
+    if s is not None:
+        s = s[rand]
 
     _kwargs = copy(kwargs)
     alpha = _kwargs.pop('alpha', 0.5)
 
-    return ax.scatter(x, y, c=color, s=size, alpha=alpha, **_kwargs)
+    return ax.scatter(x, y, c=c, s=s, alpha=alpha, **_kwargs)
 
 
-def imshow(
-    *, interpolated_data: ndarray, extent: Extent, ax: Any, **kwargs,
-):
+def imshow(*, interpolated_data: ndarray, extent: Extent, ax: Any, **kwargs):
     """Plot 1d interpolated data as an image.
 
     Parameters
@@ -134,9 +131,7 @@ def imshow(
     )
 
 
-def contour(
-    *, interpolated_data: ndarray, extent: Extent, ax: Any, **kwargs,
-):
+def contour(*, interpolated_data: ndarray, extent: Extent, ax: Any, **kwargs):
     """Plot 1d interpolated data as a contour plot.
 
     Parameters
@@ -163,9 +158,7 @@ def contour(
     return ax.contour(X, Y, interpolated_data, **kwargs)
 
 
-def quiver(
-    *, interpolated_data: ndarray, extent: Extent, ax: Any, **kwargs,
-):
+def quiver(*, interpolated_data: ndarray, extent: Extent, ax: Any, **kwargs):
     """Plot 2d interpolated data as a quiver plot.
 
     Parameters
@@ -209,9 +202,7 @@ def quiver(
     return ax.quiver(X, Y, U, V, **_kwargs)
 
 
-def streamplot(
-    *, interpolated_data: ndarray, extent: Extent, ax: Any, **kwargs,
-):
+def streamplot(*, interpolated_data: ndarray, extent: Extent, ax: Any, **kwargs):
     """Plot 2d interpolated data as a stream plot.
 
     Parameters
